==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-en-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0 - Phone\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Edit phone settings"
: "Edit phone settings"

, "Dial number"
: "Dial number"

, "Initiate a new outgoing call"
: "Initiate a new outgoing call"

, "Phones"
: "Phones"

, "No phone selected"
: "No phone selected"

, "Please select the desired phone in the tree!"
: "Please select the desired phone in the tree!"

, "Call contact"
: "Call contact"

, "Work"
: "Work"

, "Home"
: "Home"

, "Cell"
: "Cell"

, "Cell private"
: "Cell private"

, "Incoming call"
: "Incoming call"

, "Outgoing call"
: "Outgoing call"

, "unknown number"
: "unknown number"

, "Phone"
: "Phone"

, "Line"
: "Line"

, "Number"
: "Number"

, "Cancel"
: "Cancel"

, "Dial"
: "Dial"

, "Error"
: "Error"

, "Not possible to dial."
: "Not possible to dial."

, "local prefix for outgoing calls"
: "local prefix for outgoing calls"

, "telephone area code"
: "telephone area code"

, "regex for local calls"
: "regex for local calls"

, "identifies if a calling number is a local call without leading area code"
: "identifies if a calling number is a local call without leading area code"

, "own telephone number"
: "own telephone number"

, "own telephone number to prefix to internal calls"
: "own telephone number to prefix to internal calls"

, "Calls this week"
: "Calls this week"

, "Incoming and outgoing calls of this week"
: "Incoming and outgoing calls of this week"

, "Calls last week"
: "Calls last week"

, "Incoming and outgoing calls of last week"
: "Incoming and outgoing calls of last week"

, "Calls this month"
: "Calls this month"

, "Incoming and outgoing calls of this month"
: "Incoming and outgoing calls of this month"

, "Calls last month"
: "Calls last month"

, "Incoming and outgoing calls of last month"
: "Incoming and outgoing calls of last month"

, "Settings"
: "Settings"

, "Lines"
: "Lines"

, "Description"
: "Description"

, "Call"
: "Call"

, "Calls"
: "Calls"

, "Caller Id"
: "Caller Id"

, "Start"
: "Start"

, "Connected"
: "Connected"

, "Disconnected"
: "Disconnected"

, "Duration"
: "Duration"

, "Ringing"
: "Ringing"

, "Direction"
: "Direction"

, "Source"
: "Source"

, "Destination"
: "Destination"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.08.8.tar.bz2: Phone/js/Phone-lang-en-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0 - Phone\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Incoming call"
: "Incoming call"

, "Outgoing call"
: "Outgoing call"

, "unknown number"
: "unknown number"

, "Phone"
: "Phone"

, "Line"
: "Line"

, "Number"
: "Number"

, "Cancel"
: "Cancel"

, "Dial"
: "Dial"

, "Error"
: "Error"

, "Not possible to dial."
: "Not possible to dial."

, "Call contact"
: "Call contact"

, "Work"
: "Work"

, "Home"
: "Home"

, "Cell"
: "Cell"

, "Cell private"
: "Cell private"

, "Edit phone settings"
: "Edit phone settings"

, "Dial number"
: "Dial number"

, "Initiate a new outgoing call"
: "Initiate a new outgoing call"

, "Phones"
: "Phones"

, "No phone selected"
: "No phone selected"

, "Please select the desired phone in the tree!"
: "Please select the desired phone in the tree!"

, "Calls this week"
: "Calls this week"

, "Calls last week"
: "Calls last week"

, "Calls this month"
: "Calls this month"

, "Calls last month"
: "Calls last month"

, "Incoming and outgoing calls of this week"
: "Incoming and outgoing calls of this week"

, "Incoming and outgoing calls of last week"
: "Incoming and outgoing calls of last week"

, "Incoming and outgoing calls of this month"
: "Incoming and outgoing calls of this month"

, "Incoming and outgoing calls of last month"
: "Incoming and outgoing calls of last month"

, "Local prefix for outgoing calls"
: "Local prefix for outgoing calls"

, "telephone area code"
: "telephone area code"

, "regex for local calls"
: "regex for local calls"

, "Identifies if a calling number is a local call without leading area code."
: "Identifies if a calling number is a local call without leading area code."

, "own telephone number"
: "own telephone number"

, "Own telephone number to prefix to internal calls."
: "Own telephone number to prefix to internal calls."

, "Call"
: "Call"

, "Calls"
: "Calls"

, "Caller Id"
: "Caller Id"

, "Start"
: "Start"

, "Connected"
: "Connected"

, "Disconnected"
: "Disconnected"

, "Duration"
: "Duration"

, "Ringing"
: "Ringing"

, "Direction"
: "Direction"

, "Source"
: "Source"

, "Destination"
: "Destination"

, "resolved destination"
: "resolved destination"

, "Settings"
: "Settings"

, "Lines"
: "Lines"

, "Description"
: "Description"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
